@@ -30,9 +30,9 @@ class TestDataLoader(unittest.TestCase):
 
     def testMask(self):
         for i in tfkit.gen_mask.get_data_from_file(os.path.join(TestDataLoader.DATASET_DIR, 'mask.csv')):
-            print(i)
+            print("get_data_from_file", i)
 
-        maxlen = 100
+        maxlen = 512
         for i in tfkit.gen_mask.loadMaskDataset(os.path.join(TestDataLoader.DATASET_DIR, 'mask.csv'),
                                                 pretrained_config='voidful/albert_chinese_tiny',
                                                 maxlen=maxlen):
@@ -96,7 +96,6 @@ class TestDataLoader(unittest.TestCase):
             print(tokenizer.convert_tokens_to_string(output) + "\n")
 
     def testClassifier(self):
-
         for i in tfkit.classifier.get_data_from_file(os.path.join(TestDataLoader.DATASET_DIR, 'classification.csv')):
             print(i)
         for i in tfkit.classifier.loadClassifierDataset(os.path.join(TestDataLoader.DATASET_DIR, 'classification.csv'),
@@ -121,6 +120,7 @@ class TestDataLoader(unittest.TestCase):
         for i in tfkit.qa.loadQADataset(os.path.join(TestDataLoader.DATASET_DIR, 'qa.csv'),
                                         pretrained='voidful/albert_chinese_small',
                                         maxlen=512):
+            print(i)
             self.assertTrue(len(i['input']) <= 512)
             self.assertTrue(len(i['target']) == 2)
         for i in tfkit.qa.loadQADataset(os.path.join(TestDataLoader.DATASET_DIR, 'qa.csv'),
@@ -133,14 +133,14 @@ class TestDataLoader(unittest.TestCase):
         ds = tfkit.qa.loadQADataset(os.path.join(TestDataLoader.DATASET_DIR, 'qa.csv'),
                                     pretrained='voidful/albert_chinese_small',
                                     maxlen=512)
-        print(ds.__len__())
-        ds.increase_with_sampling(20)
-        self.assertTrue(ds.__len__() == 20)
+        old_len = ds.__len__()
+        ds.increase_with_sampling(10)
+        self.assertTrue(ds.__len__() == old_len)
 
         ds = tfkit.qa.loadQADataset(os.path.join(TestDataLoader.DATASET_DIR, 'qa.csv'),
                                     pretrained='voidful/albert_chinese_small',
                                     maxlen=512)
         print("before increase_with_sampling", ds.__len__())
-        ds.increase_with_sampling(12)
+        ds.increase_with_sampling(50)
         print("after increase_with_sampling", ds.__len__())
-        self.assertTrue(ds.__len__() == 12)
+        self.assertTrue(ds.__len__() == 50)
