@@ -3,7 +3,7 @@ import random
 import nlp2
 import torch
 from tqdm import tqdm
-from transformers import AdamW, BertTokenizer, AutoTokenizer, AutoModel
+from transformers import BertTokenizer, AutoTokenizer, AutoModel
 import numpy as np
 import tensorboardX as tensorboard
 from torch.utils import data
@@ -91,6 +91,7 @@ def model_eval(models, test_dataset, fname, epoch, writer):
                 test_batch = next(batch, None)
                 if test_batch is not None:
                     loss = model(test_batch)
+                    loss = loss / input_arg.grad_accum
                     t_loss += loss.mean().item()
                     t_length += 1
                     pbar.update(1)
@@ -144,7 +145,7 @@ def _load_model_and_data(pretrained_config, tokenizer, pretrained, device):
             inputted_arg = {"pretrained_config": pretrained_config, "maxlen": input_arg.maxlen,
                             "cache": input_arg.cache, "likelihood": model_type}
             all_arg = nlp2.function_get_all_arg_with_value(gen_onebyone.loadOneByOneDataset)
-            if input_arg.enable_arg_panel:
+            if input_arg.panel:
                 for missarg in nlp2.function_check_missing_arg(gen_onebyone.loadOneByOneDataset,
                                                                inputted_arg):
                     panel.add_element(k=missarg, v=all_arg[missarg], msg=missarg, default=all_arg[missarg])
@@ -212,7 +213,7 @@ def main():
     parser.add_argument('--tensorboard', dest='tensorboard', action='store_true', help='Turn on tensorboard graphing')
     parser.add_argument("--resume", help='resume training')
     parser.add_argument("--cache", action='store_true', help='cache training data')
-    parser.add_argument("--enable_arg_panel", action='store_true', help="enable panel to input argument")
+    parser.add_argument("--panel", action='store_true', help="enable panel to input argument")
     global input_arg
     input_arg = parser.parse_args()
 
